import { ref } from 'vue';
import { ElMessage } from 'element-plus';

// 一般是指项目路由的前缀部分
const prefix = '/api/util/dbInit/';
// 确定具体接口位置
const target = 'project';
// 拼装成全路由,如果需要再拼接,自己到方法里去拼
const route = `${prefix}${target}`;
/**
 * api初始化函数
 * @return {Object} 返回该api自带的变量与函数
 * @property {Array} list 查询列表的数组结果
 * @property {Number} total 查询列表符合条件的总数
 */
const init = function () {
  let list = ref([]);
  let total = ref(0);
  // 下面5个接口是针对单表的常规接口,可以全写,但是服务端不一定全都开放使用
  /**
   * 多查,根据条件返回数据列表
   * @param {Object} query 查询条件
   * @property {Number/String} skip 起始索引,可以直接解构出来
   * @property {Number/String} limit 查询显示数量,可以直接解构出来
   * @property {Object} condition 其余的条件,需要知道key才可以单独解构出想要的
   */
  const query = async function (query) {
    const res = await this.$axios.$get(`${route}`, query);
    if (this.$checkRes(res)) {
      list.value = res.data;
      total.value = res.total;
    }
  };
  /**
   * 单查,根据id找到唯一数据,返回数据
   * @param {String} id 数据id
   * @return {Object} 查询到的数据
   */
  const fetch = async function (id) {
    const res = await this.$axios.$get(`${route}/${id}`);
    if (this.$checkRes(res)) {
      return res.data;
    }
  };
  /**
   * 创建数据
   * @param {Object} data 数据
   * @return {Object} 创建的数据结果
   */
  const create = async function (data) {
    const res = await this.$axios.$post(`${route}`, data);
    if (this.$checkRes(res, '创建成功', '创建失败')) {
      return res.data;
    } else {
      console.error(`${target}-error:`);
      console.error(res.errmsg);
    }
  };
  /**
   * 修改数据
   * @param {Object} params
   * @returns
   */
  const update = async function ({ id, _id, ...data }) {
    if (!id && !_id) {
      ElMessage.error('缺少要修改的数据信息,无法修改');
      return false;
    }
    const res = await this.$axios.$post(`${route}/${id}`, data);
    if (this.$checkRes(res, '修改成功', '修改失败')) {
      return res.data;
    } else {
      console.error(`${target}-error:`);
      console.error(res.errmsg);
    }
  };
  /**
   * 删除数据
   * @param {String} id 数据id
   * @returns 是否成功
   */
  const destory = async function (id) {
    if (!id) {
      ElMessage.error('缺少要修改的数据信息,无法修改');
      return false;
    }
    const res = await this.$axios.$delete(`${route}/${id}`);
    if (this.$checkRes(res, '删除成功', '删除失败')) {
      return true;
    } else {
      console.error(`${target}-error:`);
      console.error(res.errmsg);
    }
  };
  return { list, total, query, create, fetch, update, destory };
};
export default init;
